#!/bin/bash
#
# statsnet.sh - A small script to output total sent bytes and packets for NIC's.
# Copyright (C) 2002 Oskar Andreasson
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
# USA
#

#
# Config options.
#


if [ -f $HOME/.statsnetrc ]; then
	. $HOME/.statsnetrc
elif [ -f /etc/statsnet.conf ]; then
	. /etc/statsnet.conf
else
	echo "No config files"
	return 0
fi

#######
# Code
#

REFRESH=$(($UPDATE * $INTERVAL))

#
# Create connections images and html file.
#

${RRDTOOL} graph --start -3600 --end N --title "Connections 1 hour" \
	--lower-limit 0 ${OUTDIR}connections-1hour.gif \
	DEF:conns=${DATAFILE}:connections:AVERAGE \
	LINE2:conns#FF0000:"Connections in conntrack" >> /dev/null

${RRDTOOL} graph --start -86400 --end N --title "Connections 1 day" \
	--lower-limit 0 ${OUTDIR}connections-1day.gif \
	DEF:conns=${DATAFILE}:connections:AVERAGE \
	LINE2:conns#FF0000:"Connections in conntrack" >> /dev/null

${RRDTOOL} graph --start -604800 --end N --title "Connections 1 week" \
	--lower-limit 0 ${OUTDIR}connections-1week.gif \
	DEF:conns=${DATAFILE}:connections:AVERAGE \
	LINE2:conns#FF0000:"Connections in conntrack" >> /dev/null

${RRDTOOL} graph --start -2592000 --end N --title "Connections 1 month" \
	--lower-limit 0 ${OUTDIR}connections-1month.gif \
	DEF:conns=${DATAFILE}:connections:AVERAGE \
	LINE2:conns#FF0000:"Connections in conntrack" >> /dev/null

echo "<META HTTP-EQUIV=Refresh CONTENT=\"$REFRESH\">" >> ${OUTDIR}connections.html
echo "<HTML><BODY>" > ${OUTDIR}connections.html
echo "<B>Network connections statistics</B><P>" >> ${OUTDIR}connections.html
echo "<IMG SRC=\"connections-1hour.gif\"><P>" >> ${OUTDIR}connections.html
echo "<IMG SRC=\"connections-1day.gif\"><P>" >> ${OUTDIR}connections.html
echo "<IMG SRC=\"connections-1week.gif\"><P>" >> ${OUTDIR}connections.html
echo "<IMG SRC=\"connections-1month.gif\"><P>" >> ${OUTDIR}connections.html
echo "</BODY></HTML>" >> ${OUTDIR}connections.html

#
# TX/RX Bytes images and HTML
#

${RRDTOOL} graph --start -3600 --end N --title "Bytes 1 hour" \
	--lower-limit 0 ${OUTDIR}bytes-1hour.gif \
	DEF:txbytes=${DATAFILE}:tx_bytes:AVERAGE \
		LINE1:txbytes#FF0000:"TX bytes/minute" \
	DEF:rxbytes=${DATAFILE}:rx_bytes:AVERAGE \
		LINE2:rxbytes#00FF00:"RX bytes/minute" \
	>> /dev/null

${RRDTOOL} graph --start -86400 --end N --title "Bytes 1 day" \
	--lower-limit 0 ${OUTDIR}bytes-1day.gif \
	DEF:txbytes=${DATAFILE}:tx_bytes:AVERAGE \
		LINE1:txbytes#FF0000:"TX bytes/minute" \
	DEF:rxbytes=${DATAFILE}:rx_bytes:AVERAGE \
		LINE2:rxbytes#00FF00:"RX bytes/minute" \
	>> /dev/null

${RRDTOOL} graph --start -604800 --end N --title "Bytes 1 week" \
	--lower-limit 0 ${OUTDIR}bytes-1week.gif \
	DEF:txbytes=${DATAFILE}:tx_bytes:AVERAGE \
		LINE1:txbytes#FF0000:"TX bytes/minute" \
	DEF:rxbytes=${DATAFILE}:rx_bytes:AVERAGE \
		LINE2:rxbytes#00FF00:"RX bytes/minute" \
	>> /dev/null

${RRDTOOL} graph --start -2592000 --end N --title "Bytes 1 month" \
	--lower-limit 0 ${OUTDIR}bytes-1month.gif \
	DEF:txbytes=${DATAFILE}:tx_bytes:AVERAGE \
		LINE1:txbytes#FF0000:"TX bytes/minute" \
	DEF:rxbytes=${DATAFILE}:rx_bytes:AVERAGE \
		LINE2:rxbytes#00FF00:"RX bytes/minute" \
	>> /dev/null



echo "<META HTTP-EQUIV=Refresh CONTENT=\"$REFRESH\">" >> ${OUTDIR}bytes.html
echo "<HTML><BODY>" > ${OUTDIR}bytes.html
echo "<B>Network TX/RX Bytes statistics</B><P>" >> ${OUTDIR}bytes.html
echo "<IMG SRC=\"bytes-1hour.gif\"><P>" >> ${OUTDIR}bytes.html
echo "<IMG SRC=\"bytes-1day.gif\"><P>" >> ${OUTDIR}bytes.html
echo "<IMG SRC=\"bytes-1week.gif\"><P>" >> ${OUTDIR}bytes.html
echo "<IMG SRC=\"bytes-1month.gif\"><P>" >> ${OUTDIR}bytes.html
echo "</BODY></HTML>" >> ${OUTDIR}bytes.html

#
# TX/RX Packets images and HTML
#

${RRDTOOL} graph --start -3600 --end N --title "Packets 1 hour" \
	--lower-limit 0 ${OUTDIR}pkts-1hour.gif \
	DEF:txpkts=${DATAFILE}:tx_pkts:AVERAGE \
		LINE1:txpkts#FF0000:"TX packets/minute" \
	DEF:rxpkts=${DATAFILE}:rx_pkts:AVERAGE \
		LINE2:rxpkts#00FF00:"RX packets/minute" \
	>> /dev/null

${RRDTOOL} graph --start -86400 --end N --title "Packets 1 day" \
	--lower-limit 0 ${OUTDIR}pkts-1day.gif \
	DEF:txpkts=${DATAFILE}:tx_pkts:AVERAGE \
		LINE1:txpkts#FF0000:"TX packets/minute" \
	DEF:rxpkts=${DATAFILE}:rx_pkts:AVERAGE \
		LINE2:rxpkts#00FF00:"RX packets/minute" \
	>> /dev/null

${RRDTOOL} graph --start -604800 --end N --title "Packets 1 week" \
	--lower-limit 0 ${OUTDIR}pkts-1week.gif \
	DEF:txpkts=${DATAFILE}:tx_pkts:AVERAGE \
		LINE1:txpkts#FF0000:"TX packets/minute" \
	DEF:rxpkts=${DATAFILE}:rx_pkts:AVERAGE \
		LINE2:rxpkts#00FF00:"RX packets/minute" \
	>> /dev/null

${RRDTOOL} graph --start -2592000 --end N --title "Packets 1 month" \
	--lower-limit 0 ${OUTDIR}pkts-1month.gif \
	DEF:txpkts=${DATAFILE}:tx_pkts:AVERAGE \
		LINE1:txpkts#FF0000:"TX packets/minute" \
	DEF:rxpkts=${DATAFILE}:rx_pkts:AVERAGE \
		LINE2:rxpkts#00FF00:"RX packets/minute" \
	>> /dev/null

echo "<META HTTP-EQUIV=Refresh CONTENT=\"$REFRESH\">" >> ${OUTDIR}packets.html
echo "<HTML><BODY>" > ${OUTDIR}packets.html
echo "<B>Network TX/RX Packets statistics</B><P>" >> ${OUTDIR}packets.html
echo "<IMG SRC=\"pkts-1hour.gif\"><P>" >> ${OUTDIR}packets.html
echo "<IMG SRC=\"pkts-1day.gif\"><P>" >> ${OUTDIR}packets.html
echo "<IMG SRC=\"pkts-1week.gif\"><P>" >> ${OUTDIR}packets.html
echo "<IMG SRC=\"pkts-1month.gif\"><P>" >> ${OUTDIR}packets.html
echo "</BODY></HTML>" >> ${OUTDIR}packets.html

